SectionConfig class

Model representing a section in the form.

Constructors

SectionConfig({required String id, String? title, String? description, bool collapsible = false, bool initiallyExpanded = true, required List<FieldConfig> fields})
Creates a SectionConfig instance.
SectionConfig.fromJson(Map<String, dynamic> json)
Creates a SectionConfig from a JSON map.
factory

Properties

collapsible → bool
Whether the section is collapsible.
final
description → String?
Optional description for the section.
final
fields → List<FieldConfig>
List of field configurations in the section.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the section.
final
initiallyExpanded → bool
Whether the section is initially expanded (only for collapsible sections).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Optional title for the section.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited